xtesting package
================

.. automodule:: xtesting
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    xtesting.ci
    xtesting.core
    xtesting.utils

